"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@oclif/core");
const chalk = require("chalk");
const base_1 = require("../../base");
const create_1 = require("./create");
class Index extends base_1.AutocompleteBase {
    async run() {
        const { args, flags } = await this.parse(Index);
        const shell = args.shell || this.determineShell(this.config.shell);
        this.errorIfNotSupportedShell(shell);
        core_1.ux.action.start(`${chalk.bold('Building the autocomplete cache')}`);
        await create_1.default.run([], this.config);
        core_1.ux.action.stop();
        if (!flags['refresh-cache']) {
            const bin = this.config.bin;
            const tabStr = this.getTabStr(shell);
            const setupStep = this.getSetupStep(shell, bin);
            const note = this.getNote(shell);
            this.log(`
${chalk.bold(`Setup Instructions for ${bin.toUpperCase()} CLI Autocomplete ---`)}

1) ${setupStep}

NOTE: ${note}

2) Test it out, e.g.:
${chalk.cyan(`$ ${bin} ${tabStr}`)}                 # Command completion
${chalk.cyan(`$ ${bin} command --${tabStr}`)}       # Flag completion

Enjoy!
`);
        }
    }
    getSetupStep(shell, bin) {
        switch (shell) {
            case 'bash':
            case 'zsh':
                return `Add the autocomplete env var to your ${shell} profile and source it
${chalk.cyan(`$ printf "$(${bin} autocomplete:script ${shell})" >> ~/.${shell}rc; source ~/.${shell}rc`)}`;
            case 'fish':
                return `Update your shell to load the new completions
${chalk.cyan('source ~/.config/fish/config.fish')}`;
            default:
                return '';
        }
    }
    getNote(shell) {
        switch (shell) {
            case 'bash':
                return 'If your terminal starts as a login shell you may need to print the init script into ~/.bash_profile or ~/.profile.';
            case 'fish':
                return 'This assumes your Fish configuration is stored at ~/.config/fish/config.fish';
            case 'zsh':
                return `After sourcing, you can run \`${chalk.cyan('$ compaudit -D')}\` to ensure no permissions conflicts are present`;
            default:
                return '';
        }
    }
    getTabStr(shell) {
        switch (shell) {
            case 'bash':
                return '<TAB><TAB>';
            case 'fish':
            case 'zsh':
                return '<TAB>';
            default:
                return '';
        }
    }
}
exports.default = Index;
Index.description = 'display autocomplete installation instructions';
Index.args = {
    shell: core_1.Args.string({ description: 'shell type', required: false }),
};
Index.flags = {
    'refresh-cache': core_1.Flags.boolean({ description: 'Refresh cache (ignores displaying instructions)', char: 'r' }),
};
Index.examples = [
    '$ <%= config.bin %> autocomplete',
    '$ <%= config.bin %> autocomplete bash',
    '$ <%= config.bin %> autocomplete fish',
    '$ <%= config.bin %> autocomplete zsh',
    '$ <%= config.bin %> autocomplete --refresh-cache',
];
